@@ -1,4 +1,4 @@
-# (C) Copyright 2014-2015 Hewlett Packard Enterprise Development Company LP
+# (C) Copyright 2014-2016 Hewlett Packard Enterprise Development Company LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -50,6 +50,9 @@ class AlarmProcessor(BaseProcessor):
             'newState',
             'oldState',
             'stateChangeReason',
+            'severity',
+            'link',
+            'lifecycleState',
             'tenantId',
             'timestamp'
         ]
